==> nextcloud-app-tasks-0.14.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sc.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Fainas imbenientes",
    "Important" : "Importante",
    "Today" : "Oe",
    "Week" : "Chida",
    "All" : "Totu",
    "Current" : "Atuale",
    "Completed" : "Cumpletadu",
    "Tasks" : "Fainas",
    "The Tasks app for Nextcloud" : "S'aplicatzione de is fainas de Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "Candu ativadu, unu menu Fainas nou at a aparèssere in su menu de is aplicatziones de Nextcloud. Dae cue podes agiùnghere o cantzellare fainas, modificare tìtulu, descritzione, datas de cumintzu e fine e ddas podes marcare comente de importu. Faghet a cumpartzire is fainas intre utentes. Faghet a ddas sincronizare cun CalDav (ogni lista de faina est collegada a unu calendàriu Nextcloud, pro ddu sincronizare cun su cliente locale tuo - Thunderbird, Evolution, KDE Kontact, iCal, … - bastat a agiùnghere su calendàriu comente unu calendàriu remotu in su cliente tuo). Podes iscarrigare is fainas tuas comente archìvios ICS impreende su butone de iscarrigamentu pro ogni calendàriu.",
    "Default list" : "Lista predefinida",
    "Visibility of Smart Collections" : "Visibilidade de colletziones intelligentes",
    "Hidden" : "Cuadu",
    "Visible" : "Visìbile",
    "Automatic" : "Automàticu",
    "Share with users or groups" : "Cumpartzi cun utentes o grupos",
    "No users or groups" : "Peruna utèntzia o grupos",
    "Can edit" : "Podet modificare",
    "Unshare with {displayName}" : "Annulla sa cumpartzidura cun {displayName}",
    "Unable to delete the share." : "Non faghet a cantzellare sa cumpartzidura.",
    "Unable to change permissions." : "Non faghet a cambiare is permissos.",
    "Edit" : "Modìfica ",
    "Copy private link" : "Còpia ligòngiu privadu",
    "Copied" : "Copiadu",
    "Cannot copy" : "Non faghet a copiare",
    "Download" : "Iscàrriga",
    "Delete" : "Cantzella",
    "Unshare" : "Annulla sa cumpartzidura",
    "Cancel" : "Annulla",
    "Save" : "Sarva",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Custu at a cantzellare su calendàriu \"{calendar}\" e totu is eventos e fainas chi ddi currispondent.",
    "This will unshare the calendar \"{calendar}\"." : "Custu at a annullare sa cumpartzidura de su calendàriu \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Custu at a cantzellare sa lista \"{list}\" e totu is fainas chi ddi currispondent.",
    "This will unshare the list \"{list}\"." : "Custu at a annullare sa cumpartzidura de sa lista \"{list}\".",
    "Calendar link copied to clipboard." : "Ligòngiu de su calendàriu cipiadu in punta de billete.",
    "List link copied to clipboard." : "Ligòngiu de sa lista copiadu in punta de billete.",
    "Calendar link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu de su calendàriu in punta de billete.",
    "List link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu de sa lista in punta de billete.",
    "The name \"{calendar}\" is already used." : "Su nùmene \"{calendar}\" est giai impreadu.",
    "An empty name is not allowed." : "Unu nùmene bòidu no est permìtidu.",
    "An error occurred, unable to delete the calendar." : "B'at àpidu un'errore, no at fatu a cantzellare su calendàriu.",
    "An error occurred, unable to delete the list." : "B'at àpidu un'errore, no at fatu a cantzellare sa lista.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Su calendàriu s'at a cantzellare intre {countdown} segundu","Su calendàriu s'at a cantzellare intre {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Annullamentu de sa cumpartzidura de su calendàriu intre {countdown} segundu","Annullamentu de sa cumpartzidura de su calendàriu intre {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sa lista s'at a cantzellare intre {countdown} segundu","Sa lista s'at a cantzellare intre {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Sa lista s'at a cantzellare intre {countdown} segundu","Annullamentu de sa cumpartzidura de sa lista intre {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Cumpartzidu cun {num} entidade","Cumpartzidu cun {num} entidades"],
    "Set date" : "Imposta data",
    "Set time" : "Imposta ora",
    "Delete date" : "Cantzella data",
    "Click here to add a note." : "Incarca inoghe pro agiùnghere una nota.",
    "Set value" : "Imposta balore",
    "Delete value" : "Cantzella balore",
    "Add this as a new tag" : "Agiunghe custa comente eticheta noa",
    "No tag available. Create one!" : "Peruna eticheta a disponimentu. Crea·dda!",
    "Delete all completed tasks." : "Cantzella totu is fainas cumpletadas.",
    "Delete completed tasks." : "Cantzella is fainas cumpletadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Cantzelladas totu is fainas cumpletadas dae su calendàriu \"{calendar}\".",
    "No errors" : "Perunu errore",
    "Open your browser console for more details" : "Aberi sa consolla de su navigadore pro àteros detàllios",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Custu at a cantzellare {taskCount} faina cumpletada e is suta-fainas suas dae su calendàriu \"{calendar}\".","Custu at a cantzellare {taskCount} fainas cumpletadas e is suta-fainas suas dae su calendàriu \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No at fatu a cantzellare {failedCount} faina.","No at fatu a cantzellare {failedCount} fainas."],
    "Add an important task to \"{calendar}\"…" : "Agiunghe una faina importante in \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Agiunghe una faina chi agabbat oe a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Agiunghe una faina atuale in \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Agiunghe una faina a \"{calendar}\"…",
    "Load all completed tasks." : "Càrriga totu is fainas cumpletadas.",
    "Change sort order" : "Càmbia s'ordinamentu",
    "Relevance" : "Importàntzia",
    "Sort by completed state, due date, priority, start date and summary." : "Assenta segundu istadu cumpletadu, data de fine, prioridade, data e cumintzu e resumu.",
    "Start date" : "Data de cumintzu",
    "Sort by start date and summary." : "Assentadu segundu data de cumintzu e resumu.",
    "Due date" : "Data de fine",
    "Sort by due date and summary." : "Assenta segundu data de fine e resumu.",
    "Created date" : "Data de creatzione",
    "Sort by created date and summary." : "Assenta segundu data de creatzione e resumu.",
    "Last modified" : "Ùrtima modìfica",
    "Sort by last-modified date and summary." : "Assenta segundu ùrtima modìfica e resumu.",
    "Completed date" : "Data de cumpletamentu",
    "Sort by completed date." : "Assenta segundu data de cumpletamentu.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Assenta segundu prioridade e resumu.",
    "Alphabetically" : "Òrdine alfabèticu",
    "Sort by summary and priority." : "Assenta segundu resumu e prioridade.",
    "Manually" : "A manu",
    "Sort by manual order." : "Assenta segundu ordine manuale.",
    "Task is completed" : "Sa faina est cumpletada",
    "{complete} % completed" : "{complete} % cumpletadu",
    "Task has hidden subtasks" : "Sa faina tenet suta-fainas cuadas",
    "Task is pinned" : "Sa faina est apicada",
    "Task has a note" : "Sa faina tenet una nota",
    "Add subtask" : "Agiunghe suta-faina",
    "Show subtasks" : "Mustra suta-fainas",
    "Hide subtasks" : "Cua suta-fainas",
    "Show closed subtasks" : "Mustra suta-fainas serradas",
    "Hide closed subtasks" : "Cua suta-fainas serradas",
    "Delete task" : "Cantzella faina",
    "Toggle starred" : "Ativa/disativa preferidu",
    "[Yesterday]" : "[Eris]",
    "[Today]" : "[Oe]",
    "[Tomorrow]" : "[Cras]",
    "[Completed yesterday]" : "[Cumpletadu eris]",
    "[Completed today]" : "[Cumpletadu oe]",
    "[Completed tomorrow]" : "[Cumpletadu cras]",
    "[Yesterday at] LT" : "[Eris a is] LT",
    "[Today at] LT" : "[Oe a is] LT",
    "[Tomorrow at] LT" : "[Cras a is] LT",
    "L [at] LT" : "L [a is] LT",
    "[Completed yesterday at] LT" : "[Cumpletadu a is] LT",
    "[Completed today at] LT" : "[Cumpletadu oe a is] LT",
    "[Completed tomorrow at] LT" : "[Cumpletadu cras a is] LT",
    "[Completed] L [at] LT" : "[Cumpletadu] L [a is] LT",
    "Add a subtask to \"{task}\"…" : "Agiunghe una suta-faina a \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Sa faina s'at a cantzellare intre {countdown} segundu","Sa faina s'at a cantzellare intre {countdown} segundos"],
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Faina cumpletada","%n Fainas cumpletadas"],
    "Tomorrow" : "Cras",
    "Add List…" : "Agiunghe lista...",
    "New List" : "Lista noa",
    "All day" : "Totu sa die",
    "Unpin" : "No apicare",
    "Pin" : "Apica",
    "Show in Calendar" : "Mustra in calendàriu",
    "Edit title" : "Modìfica tìtulu",
    "Details" : "Detàllios",
    "Select a classification" : "Seletziona una classificatzione",
    "Select a status" : "Seletziona un'istadu",
    "Select tags" : "Seletziona etichetas",
    "Notes" : "Notas",
    "Reminders" : "Promemòrias",
    "Repeat" : "Repiti",
    "When shared show full event" : "Candu si cumpartzit, mustra totu s'eventu",
    "When shared show only busy" : "Cando si cumpartzit, mustra isceti ocupadu",
    "When shared hide this event" : "Cando si cumpartzit, cua custu eventu",
    "[Completed] L" : "[Cumpletadu] L",
    "[Completed last] dddd [at] LT" : "[Cumpletadu s'ùrtima borta] dddd [a is] LT",
    "[Completed] dddd [at] LT" : "[Cumpletadu] dddd [a is] LT",
    "[Last modified yesterday at] LT" : "[Ùrtima modìfica eris a is] LT",
    "[Last modified today at] LT" : "[Ùrtima modìfica oe a is] LT",
    "[Last modified] L" : "[Ùrtima modìfica] L",
    "[Last modified last] dddd [at] LT" : "[Ùrtima modìfica su passadu] dddd [a is] LT",
    "[Last modified] dddd [at] LT" : "[Ùrtima modìfica] dddd [a is] LT",
    "[Created yesterday at] LT" : "[Creadu eris a is] LT",
    "[Created today at] LT" : "[Creadu oe a is] LT",
    "[Created] L" : "[Creadu] L",
    "[Created last] dddd [at] LT" : "[Creadu s'ùrtima borta] dddd [a is] LT",
    "[Created] dddd [at] LT" : "[Creadu] dddd [a is] LT",
    "Needs action" : "Tenet bisòngiu de un'atzione",
    "In process" : "In cursu",
    "Canceled" : "Cantzelladu",
    "Clear status" : "Lìmpia istadu",
    "Loading task from server." : "Carrighende is fainas dae su serbidore.",
    "Task not found!" : "Faina no agatada!",
    "[Starts today]" : "[Cumintzat oe]",
    "[Starts tomorrow]" : "[Cumintzat cras]",
    "[Starts on] LL" : "[Cumintzat su] LL",
    "[Started yesterday]" : "[Est cumintzadu eris]",
    "[Started on] LL" : "[Est cumintzadu su] LL",
    "[Started today at] LT" : "[Est cumintzadu oe a is] LT",
    "[Starts today at] LT" : "[Cumintzat oe a is] LT",
    "[Starts tomorrow at] LT" : "[Cumintzat cras a is] LT",
    "[Starts on] LL [at] LT" : "[Cumintzat su] LL [a is] LT",
    "[Started yesterday at] LT" : "[Cumintzadu eris a is] LT",
    "[Started on] LL [at] LT" : "[Cumintzadu su] LL [a is] LT",
    "Set start date" : "Imposta data de cumintzu",
    "[Due today]" : "[Agabbt oe]",
    "[Due tomorrow]" : "[Agabbat cras]",
    "[Due on] LL" : "[Agabbat su] LL",
    "[Was due yesterday]" : "[Est agabbadu eris]",
    "[Was due on] LL" : "[Est agabbadu su] LL",
    "[Was due today at] LT" : "[Est agabbadu oe a is] LT",
    "[Due today at] LT" : "[Agabbat oe a is] LT",
    "[Due tomorrow at] LT" : "[Agabbat cras a is] LT",
    "[Due on] LL [at] LT" : "[Agabbat su] LL [a is] LT",
    "[Was due yesterday at] LT" : "[Est agabbadu eris a is] LT",
    "[Was due on] LL [at] LT" : "[Est agabbadu su] LL [a is] LT",
    "Set due date" : "Imposta iscadèntzia",
    "Priority {priority}: low" : "Prioridade {priority}: bàscia",
    "Priority {priority}: medium" : "Prioridade {priority}: mèdia",
    "Priority {priority}: high" : "Prioridade {priority}: arta",
    "No priority assigned" : "Peruna prioridade assignada",
    "{percent} % completed" : "{percent} % cumpletadu",
    "No upcoming tasks" : "Peruna faina imbeniente",
    "upcoming tasks" : "fainas imbenientes",
    "No tasks today" : "Peruna faina oe",
    "Successfully created the task." : "Faina creada.",
    "Could not delete the task." : "No at fatu a cantzellare sa faina.",
    "Synchronizing to the server." : "Sincronizatzione cun su serbidore.",
    "Task successfully saved to server." : "Faina sarvada in su serbidore.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No at fatu a agiornare sa faina ca s'est modificada in su serbidore. Incarca pro atualizare, is modìficas locales ant a èssere iscartadas.",
    "Could not update the task." : "No at fatu a agiornare sa faina.",
    "Successfully updated the task." : "Faina agiornada.",
    "Task successfully moved to new calendar." : "Faina tramudada a su calendàriu nou.",
    "An error occurred" : "B'at àpidu un'errore"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/sc.js <==
OC.L10N.register(
    "tasks",
    {
    "Upcoming tasks" : "Fainas imbenientes",
    "Important" : "Importante",
    "Today" : "Oe",
    "Week" : "Chida",
    "All" : "Totu",
    "Current" : "Atuale",
    "Completed" : "Cumpletadu",
    "Tasks" : "Fainas",
    "The Tasks app for Nextcloud" : "S'aplicatzione de is fainas de Nextcloud",
    "Default list" : "Lista predefinida",
    "Visibility of Smart Collections" : "Visibilidade de colletziones intelligentes",
    "Hidden" : "Cuadu",
    "Visible" : "Visìbile",
    "Automatic" : "Automàticu",
    "Share with users or groups" : "Cumpartzi cun utentes o grupos",
    "No users or groups" : "Peruna utèntzia o grupos",
    "Can edit" : "Podet modificare",
    "Unshare with {displayName}" : "Annulla sa cumpartzidura cun {displayName}",
    "Unable to delete the share." : "Non faghet a cantzellare sa cumpartzidura.",
    "Unable to change permissions." : "Non faghet a cambiare is permissos.",
    "Edit" : "Modìfica ",
    "Copy private link" : "Còpia ligòngiu privadu",
    "Copied" : "Copiadu",
    "Cannot copy" : "Non faghet a copiare",
    "Export" : "Esporta",
    "Delete" : "Cantzella",
    "Unshare" : "Annulla sa cumpartzidura",
    "Save" : "Sarva",
    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "Custu at a cantzellare su calendàriu \"{calendar}\" e totu is eventos e fainas chi ddi currispondent.",
    "This will unshare the calendar \"{calendar}\"." : "Custu at a annullare sa cumpartzidura de su calendàriu \"{calendar}\".",
    "This will delete the list \"{list}\" and all corresponding tasks." : "Custu at a cantzellare sa lista \"{list}\" e totu is fainas chi ddi currispondent.",
    "This will unshare the list \"{list}\"." : "Custu at a annullare sa cumpartzidura de sa lista \"{list}\".",
    "Calendar link copied to clipboard." : "Ligòngiu de su calendàriu cipiadu in punta de billete.",
    "List link copied to clipboard." : "Ligòngiu de sa lista copiadu in punta de billete.",
    "Calendar link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu de su calendàriu in punta de billete.",
    "List link could not be copied to clipboard." : "No at fatu a copiare su ligòngiu de sa lista in punta de billete.",
    "The name \"{calendar}\" is already used." : "Su nùmene \"{calendar}\" est giai impreadu.",
    "An empty name is not allowed." : "Unu nùmene bòidu no est permìtidu.",
    "An error occurred, unable to delete the calendar." : "B'at àpidu un'errore, no at fatu a cantzellare su calendàriu.",
    "An error occurred, unable to delete the list." : "B'at àpidu un'errore, no at fatu a cantzellare sa lista.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Su calendàriu s'at a cantzellare intre {countdown} segundu","Su calendàriu s'at a cantzellare intre {countdown} segundos"],
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Annullamentu de sa cumpartzidura de su calendàriu intre {countdown} segundu","Annullamentu de sa cumpartzidura de su calendàriu intre {countdown} segundos"],
    "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["Sa lista s'at a cantzellare intre {countdown} segundu","Sa lista s'at a cantzellare intre {countdown} segundos"],
    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["Sa lista s'at a cantzellare intre {countdown} segundu","Annullamentu de sa cumpartzidura de sa lista intre {countdown} segundos"],
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Cumpartzidu cun {num} entidade","Cumpartzidu cun {num} entidades"],
    "Trash bin" : " Àliga",
    "Loading deleted calendars, tasks and events." : "Carrighende is calendàrios, fainas e eventos cantzellados.",
    "You do not have any deleted calendars, tasks or events." : "Non tenes perunu calendàriu, faina o eventu cantzelladu.",
    "Name" : "Nùmene",
    "Deleted" : "Cantzelladu",
    "Restore" : "Riprìstina",
    "Delete permanently" : "Cantzella in manera definitiva",
    "Empty trash bin" : "Bòida s'àliga",
    "Untitled task" : "Atividade chene tìtulu",
    "Untitled event" : "Eventu chene tìtulu",
    "Untitled item" : "Elementu chene tìtulu",
    "Could not load deleted calendars and objects" : "No at fatu a carrigare is calendàrios e is ogetos cantzellados",
    "Could not restore calendar or event" : "No at fatu a recuperare su calendàriu o s'eventu",
    "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["Is elementos de s'àliga s'ant a cantzellare tra {numDays} die","Is elementos de s'àliga s'ant a cantzellare tra {numDays} dies"],
    "Select a calendar" : "Seletziona unu calendàriu",
    "No calendar matches the search." : "Perunu calendàriu currispondet a sa chirca.",
    "Set date" : "Imposta data",
    "Set time" : "Imposta ora",
    "Delete date" : "Cantzella data",
    "Click here to add a note." : "Incarca inoghe pro agiùnghere una nota.",
    "Set value" : "Imposta balore",
    "Delete value" : "Cantzella balore",
    "Add this as a new tag" : "Agiunghe custa comente eticheta noa",
    "No tag available. Create one!" : "Peruna eticheta a disponimentu. Crea·dda!",
    "Delete all completed tasks." : "Cantzella totu is fainas cumpletadas.",
    "Delete completed tasks." : "Cantzella is fainas cumpletadas.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Cantzelladas totu is fainas cumpletadas dae su calendàriu \"{calendar}\".",
    "No errors" : "Perunu errore",
    "Open your browser console for more details" : "Aberi sa consolla de su navigadore pro àteros detàllios",
    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Custu at a cantzellare {taskCount} faina cumpletada e is suta-fainas suas dae su calendàriu \"{calendar}\".","Custu at a cantzellare {taskCount} fainas cumpletadas e is suta-fainas suas dae su calendàriu \"{calendar}\"."],
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["No at fatu a cantzellare {failedCount} faina.","No at fatu a cantzellare {failedCount} fainas."],
    "Add an important task to \"{calendar}\"…" : "Agiunghe una faina importante in \"{calendar}\"…",
    "Add a task due today to \"{calendar}\"…" : "Agiunghe una faina chi agabbat oe a \"{calendar}\"…",
    "Add a current task to \"{calendar}\"…" : "Agiunghe una faina atuale in \"{calendar}\"…",
    "Add a task to \"{calendar}\"…" : "Agiunghe una faina a \"{calendar}\"…",
    "Load all completed tasks." : "Càrriga totu is fainas cumpletadas.",
    "Change sort order" : "Càmbia s'ordinamentu",
    "Relevance" : "Importàntzia",
    "Sort by completed state, due date, priority, start date and summary." : "Assenta segundu istadu cumpletadu, data de fine, prioridade, data e cumintzu e resumu.",
    "Start date" : "Data de cumintzu",
    "Sort by start date and summary." : "Assentadu segundu data de cumintzu e resumu.",
    "Due date" : "Data de fine",
    "Sort by due date and summary." : "Assenta segundu data de fine e resumu.",
    "Created date" : "Data de creatzione",
    "Sort by created date and summary." : "Assenta segundu data de creatzione e resumu.",
    "Last modified" : "Ùrtima modìfica",
    "Sort by last-modified date and summary." : "Assenta segundu ùrtima modìfica e resumu.",
    "Completed date" : "Data de cumpletamentu",
    "Sort by completed date." : "Assenta segundu data de cumpletamentu.",
    "Priority" : "Prioridade",
    "Sort by priority and summary." : "Assenta segundu prioridade e resumu.",
    "Alphabetically" : "Òrdine alfabèticu",
    "Sort by summary and priority." : "Assenta segundu resumu e prioridade.",
    "Manually" : "A manu",
    "Sort by manual order." : "Assenta segundu ordine manuale.",
    "{complete} % completed" : "{complete} % cumpletadu",
    "Task has hidden subtasks" : "Sa faina tenet suta-fainas cuadas",
    "Task is pinned" : "Sa faina est apicada",
    "Task has a note" : "Sa faina tenet una nota",
    "Add subtask" : "Agiunghe suta-faina",
    "Show subtasks" : "Mustra suta-fainas",
    "Hide subtasks" : "Cua suta-fainas",
    "Show closed subtasks" : "Mustra suta-fainas serradas",
    "Hide closed subtasks" : "Cua suta-fainas serradas",
    "Delete task" : "Cantzella faina",
    "Toggle starred" : "Ativa/disativa preferidu",
    "[Yesterday]" : "[Eris]",
    "[Today]" : "[Oe]",
    "[Tomorrow]" : "[Cras]",
    "[Completed yesterday]" : "[Cumpletadu eris]",
    "[Completed today]" : "[Cumpletadu oe]",
    "[Completed tomorrow]" : "[Cumpletadu cras]",
    "[Yesterday at] LT" : "[Eris a is] LT",
    "[Today at] LT" : "[Oe a is] LT",
    "[Tomorrow at] LT" : "[Cras a is] LT",
    "L [at] LT" : "L [a is] LT",
    "[Completed yesterday at] LT" : "[Cumpletadu a is] LT",
    "[Completed today at] LT" : "[Cumpletadu oe a is] LT",
    "[Completed tomorrow at] LT" : "[Cumpletadu cras a is] LT",
    "[Completed] L [at] LT" : "[Cumpletadu] L [a is] LT",
    "Add a subtask to \"{task}\"…" : "Agiunghe una suta-faina a \"{task}\"…",
    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["Sa faina s'at a cantzellare intre {countdown} segundu","Sa faina s'at a cantzellare intre {countdown} segundos"],
    "Task is completed" : "Sa faina est cumpletada",
    "Create a new task" : "Crea una faina noa",
    "Task summary" : "Resumu de sa faina",
    "Cancel" : "Annulla",
    "Create task" : "Crea faina",
    "Creating the new task…" : "Creende sa faina noa...",
    "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" agiunta a su \"{calendar}\"",
    "Close" : "Serra",
    "Open task" : "Aberi faina",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Faina cumpletada","%n Fainas cumpletadas"],
    "Tomorrow" : "Cras",
    "Add List…" : "Agiunghe lista...",
    "New List" : "Lista noa",
    "All day" : "Totu sa die",
    "Unpin" : "No apicare",
    "Pin" : "Apica",
    "Show in Calendar" : "Mustra in calendàriu",
    "Edit title" : "Modìfica tìtulu",
    "Details" : "Detàllios",
    "Select a classification" : "Seletziona una classificatzione",
    "Select a status" : "Seletziona un'istadu",
    "Select tags" : "Seletziona etichetas",
    "Notes" : "Notas",
    "Reminders" : "Promemòrias",
    "Repeat" : "Repiti",
    "When shared show full event" : "Candu si cumpartzit, mustra totu s'eventu",
    "When shared show only busy" : "Cando si cumpartzit, mustra isceti ocupadu",
    "When shared hide this event" : "Cando si cumpartzit, cua custu eventu",
    "[Completed] L" : "[Cumpletadu] L",
    "[Completed last] dddd [at] LT" : "[Cumpletadu s'ùrtima borta] dddd [a is] LT",
    "[Completed] dddd [at] LT" : "[Cumpletadu] dddd [a is] LT",
    "[Last modified yesterday at] LT" : "[Ùrtima modìfica eris a is] LT",
    "[Last modified today at] LT" : "[Ùrtima modìfica oe a is] LT",
    "[Last modified] L" : "[Ùrtima modìfica] L",
    "[Last modified last] dddd [at] LT" : "[Ùrtima modìfica su passadu] dddd [a is] LT",
    "[Last modified] dddd [at] LT" : "[Ùrtima modìfica] dddd [a is] LT",
    "[Created yesterday at] LT" : "[Creadu eris a is] LT",
    "[Created today at] LT" : "[Creadu oe a is] LT",
    "[Created] L" : "[Creadu] L",
    "[Created last] dddd [at] LT" : "[Creadu s'ùrtima borta] dddd [a is] LT",
    "[Created] dddd [at] LT" : "[Creadu] dddd [a is] LT",
    "Needs action" : "Tenet bisòngiu de un'atzione",
    "In process" : "In cursu",
    "Canceled" : "Annulladu",
    "Clear status" : "Lìmpia istadu",
    "Loading task from server." : "Carrighende is fainas dae su serbidore.",
    "Task not found!" : "Faina no agatada!",
    "[Starts today]" : "[Cumintzat oe]",
    "[Starts tomorrow]" : "[Cumintzat cras]",
    "[Starts on] LL" : "[Cumintzat su] LL",
    "[Started yesterday]" : "[Est cumintzadu eris]",
    "[Started on] LL" : "[Est cumintzadu su] LL",
    "[Started today at] LT" : "[Est cumintzadu oe a is] LT",
    "[Starts today at] LT" : "[Cumintzat oe a is] LT",
    "[Starts tomorrow at] LT" : "[Cumintzat cras a is] LT",
    "[Starts on] LL [at] LT" : "[Cumintzat su] LL [a is] LT",
    "[Started yesterday at] LT" : "[Cumintzadu eris a is] LT",
    "[Started on] LL [at] LT" : "[Cumintzadu su] LL [a is] LT",
    "Set start date" : "Imposta data de cumintzu",
    "[Due today]" : "[Agabbt oe]",
    "[Due tomorrow]" : "[Agabbat cras]",
    "[Due on] LL" : "[Agabbat su] LL",
    "[Was due yesterday]" : "[Est agabbadu eris]",
    "[Was due on] LL" : "[Est agabbadu su] LL",
    "[Was due today at] LT" : "[Est agabbadu oe a is] LT",
    "[Due today at] LT" : "[Agabbat oe a is] LT",
    "[Due tomorrow at] LT" : "[Agabbat cras a is] LT",
    "[Due on] LL [at] LT" : "[Agabbat su] LL [a is] LT",
    "[Was due yesterday at] LT" : "[Est agabbadu eris a is] LT",
    "[Was due on] LL [at] LT" : "[Est agabbadu su] LL [a is] LT",
    "Set due date" : "Imposta iscadèntzia",
    "Priority {priority}: low" : "Prioridade {priority}: bàscia",
    "Priority {priority}: medium" : "Prioridade {priority}: mèdia",
    "Priority {priority}: high" : "Prioridade {priority}: arta",
    "No priority assigned" : "Peruna prioridade assignada",
    "{percent} % completed" : "{percent} % cumpletadu",
    "No upcoming tasks" : "Peruna faina imbeniente",
    "upcoming tasks" : "fainas imbenientes",
    "No tasks today" : "Peruna faina oe",
    "Mark as done" : "Marca comente cumpletadu",
    "No due date assigned" : "Peruna data de iscadèntzia assignada",
    "[Due yesterday]" : "[Agabbadu eris]",
    "[Due] L" : "[Agabbadu] L",
    "[Due yesterday at] LT" : "[Agabbadu eris a] LT",
    "[Due] L [at] LT" : "[Agabbadu] L [a] LT",
    "Successfully created the task." : "Faina creada.",
    "Could not delete the task." : "No at fatu a cantzellare sa faina.",
    "Synchronizing to the server." : "Sincronizatzione cun su serbidore.",
    "Task successfully saved to server." : "Faina sarvada in su serbidore.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "No at fatu a agiornare sa faina ca s'est modificada in su serbidore. Incarca pro atualizare, is modìficas locales ant a èssere iscartadas.",
    "Could not update the task." : "No at fatu a agiornare sa faina.",
    "Successfully updated the task." : "Faina agiornada.",
    "Task successfully moved to new calendar." : "Faina tramudada a su calendàriu nou.",
    "An error occurred" : "B'at àpidu un'errore",
    "Create a task" : "Crea una faina",
    "Message from {author} in {conversationName}" : "Messàgiu dae {author} in {conversationName}"
},
"nplurals=2; plural=(n != 1);");
